@@ -1,5 +1,5 @@
 facToChar <- function ( dataFrame, from = "factor", to = "character" ) {
-             if(!"data.frame" %in% class(dataFrame)) {stop("'dataFrame' must be of class 'data.frame'.")}
+             dataFrame <- makeDataFrame(dataFrame)
              classes <- which( unlist(lapply(dataFrame,class)) == from)
              if(length(classes)>0) {
                 for (u in classes) { eval(parse(text=paste("dataFrame[,u] <- as.",to,"(dataFrame[,u])",sep="") )) }}
