@@ -1,7 +1,7 @@
 # var    ... variable
 # lookup ... data.frame mit zwei spalten; erste spalte: alte Werte; zweite Spalte: neue Werte
 recodeLookup <- function (var, lookup) {
-        if(!is.data.frame(lookup) && !is.matrix(lookup)) {stop("The lookup table must be a data.frame or matrix.")}     ### checks ...
+        lookup <- makeDataFrame(lookup)
         if(ncol(lookup) != 2) {stop("The lookup table must have two colums.")}     ### checks ...
         if(length(unique(lookup[,1])) < nrow(lookup) ) { stop("Old values in lookup table are not unique.")}
         haven_labelled <- lapply(lookup, function(x) {
